@@ -1,11 +1,12 @@
 //! Functions using all supported type patterns.
 
-use crate::patterns::success_enum::FFIError;
+use crate::patterns::result::FFIError;
+use crate::patterns::service::Error;
 use crate::types::{
     ambiguous1, ambiguous2, common, some_foreign_type, Array, Callbacku8u8, Empty, EnumDocumented, EnumRenamedXYZ, Generic, Generic2, Generic3, Generic4, Opaque,
     Phantom, SomeForeignType, StructDocumented, StructRenamedXYZ, Tupled, Vec3f32, Visibility1, Visibility2, Weird1, Weird2,
 };
-use interoptopus::patterns::success_enum::panics_and_errors_to_ffi_enum;
+use interoptopus::patterns::result::panics_and_errors_to_ffi_enum;
 use interoptopus::{ffi_function, here};
 use std::ptr::null;
 use std::time::Duration;
@@ -246,8 +247,15 @@ pub extern "C" fn namespaced_type(x: common::Vec) -> common::Vec {
 
 #[ffi_function]
 #[no_mangle]
+#[allow(unreachable_code)]
 pub extern "C" fn panics() -> FFIError {
-    panics_and_errors_to_ffi_enum(|| panic!("Oh no"), here!())
+    panics_and_errors_to_ffi_enum(
+        || {
+            panic!("Oh no");
+            Ok::<(), Error>(())
+        },
+        here!(),
+    )
 }
 
 #[ffi_function]
