@@ -81,7 +81,7 @@ interoptopus::inventory!(
         patterns::primitives::pattern_ffi_bool,
         patterns::api_entry::pattern_my_api_init_v1,
         patterns::api_guard::pattern_api_guard,
-        patterns::callbacks::pattern_callback_1
+        patterns::callbacks::pattern_callback_1,
     ],
     [types::ExtraType<f32>],
     [patterns::service::SimpleService]
