@@ -1,12 +1,12 @@
 use crate::types::{CallbackFFISlice, Vec3f32};
 use interoptopus::patterns::slice::{FFISlice, FFISliceMut};
-use interoptopus::{ffi_function, pattern_callback};
+use interoptopus::{callback, ffi_function};
 
 static HUGE_VEC_SLICE: [Vec3f32; 100_000] = [Vec3f32 { x: 0.0, y: 0.0, z: 0.0 }; 100_000];
 
-pattern_callback!(CallbackHugeVecSlice(slice: FFISlice<Vec3f32>) -> Vec3f32);
+callback!(CallbackHugeVecSlice(slice: FFISlice<Vec3f32>) -> Vec3f32);
 
-pattern_callback!(CallbackSliceMut(slice: FFISliceMut<'_, u8>) -> ());
+callback!(CallbackSliceMut(slice: FFISliceMut<'_, u8>) -> ());
 
 #[ffi_function]
 #[no_mangle]
